/*
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this code; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  */

/* Copyright (C) 2002 Ian Zimmerman <itz@speakeasy.org> */

static const char rcsid[] = "$Id: search_dialog.cc,v 1.2 2002/09/09 20:21:57 itz Exp $ ";

#include "search_dialog.hh"

#include <gtk--/button.h>
#include <gtk--/entry.h>
#include <gtk--/box.h>
#include <gtk/gtkmain.h>

void
search_dialog::find_first_handler()
{
  button = find_first;
  result = p_entry->get_text();
  set_modal(0);
  destroy();
}

void
search_dialog::find_next_handler()
{
  button = find_next;
  result = p_entry->get_text();
  set_modal(0);
  destroy();
}

void
search_dialog::cancel_handler()
{
  button = cancel;
  set_modal(0);
  destroy();
}

search_dialog::buttons
search_dialog::get_button()
{
  return button;
}

const char*
search_dialog::get_result()
{
  return result.c_str();
}

search_dialog::search_dialog(const char* s)
  : Gtk::Dialog(), button(cancel)
{
  
  Gtk::HBox* p_action = get_action_area();
  Gtk::VBox* p_vbox = get_vbox();
  Gtk::HBox* p_hbox = manage(new Gtk::HBox(0, 10));

  p_entry = manage(new Gtk::Entry);
  p_entry->set_text(s);
  p_entry->select_region(0, -1);
  p_hbox->pack_start(*p_entry, 1, 1, 5);
  p_vbox->pack_start(*p_hbox, 0, 0, 5);

  Gtk::Button* p_find_first = manage(new Gtk::Button("Find first"));
  Gtk::Button* p_find_next = manage(new Gtk::Button("Find next"));
  Gtk::Button* p_cancel = manage(new Gtk::Button("Cancel"));
  p_action->pack_start(*p_find_first);
  p_action->pack_start(*p_find_next);
  p_action->pack_start(*p_cancel);
  p_find_first->clicked.connect(SigC::slot(this, &search_dialog::find_first_handler));
  p_find_next->clicked.connect(SigC::slot(this, &search_dialog::find_next_handler));
  p_cancel->clicked.connect(SigC::slot(this, &search_dialog::cancel_handler));

  // it's better to leave this up to the window manager
  //  set_position(GTK_WIN_POS_CENTER);

  show_all();
  if (*s != 0) {
    p_find_next->grab_focus();
  } else {
    p_entry->grab_focus();
  } /*if*/
  set_modal(1);
}
